.. Copyright 2014 Oliver Cope
..
.. Licensed under the Apache License, Version 2.0 (the "License");
.. you may not use this file except in compliance with the License.
.. You may obtain a copy of the License at
..
..     http://www.apache.org/licenses/LICENSE-2.0
..
.. Unless required by applicable law or agreed to in writing, software
.. distributed under the License is distributed on an "AS IS" BASIS,
.. WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
.. See the License for the specific language governing permissions and
.. limitations under the License.

CHANGELOG
=========

0.2.1 (released 2017-10-04)
---------------------------

- Added support for Python 3.5, 3.6. Dropped support for Python 3.3, 3.4


Version 0.2.0
-------------

- Dropped support for using setattr to configure subobjects. Use the double
  underscore convention instead.
- Attribute/item setting on factory objects now results in the same operation
  being carried out on the generated object. This is useful for creating
  circular references between factory objects.
- Lists of factory objects are now supported, making it easier to manage
  large numbers of test objects.
- Factories now can take a ``partial`` flag. This stops the factory from
  producing a top-level named object, while still allowing it to be used for
  the basis of other factories.

Version 0.1.6
-------------

- Added support for Python 3.4.
- Dropped support for Python 3.2.
- Tests that delete fixture objects before teardown is called no longer cause
  SQLAlchemy to invalidate the transaction (and thus potentially cause later
  tests to fail unexpectedly).
- Added a scope argument to Seq(), that determines whether the sequence counter
  is reset at the start of each fixture set up or only once, at the start of
  the test run.

Version 0.1.5
-------------

- Licensing: toffee is now licensed under the Apache License, Version 2.0
- Bugfix: Fixed exception in LazyRecorderFactory.destroy_object during fixture
  teardown

Version 0.1.4
-------------

- Added toffee.TestWithFixture

Version 0.1.3
-------------

- The data mapper factories (SQLAlchemy and Storm) support querying for
  existing objects in fixtures
- Added experimental SQLAlchemy support

Version 0.1.2
-------------

- Made setting factoryoptions more flexible. It's now possible to change the
  default flush/commit behavior of StormFactory per fixture class and or at
  setup time when using the context manager syntax.

Version 0.1.1
-------------

- Bugfix: StormFactory did not flush/commit the store on fixture teardown
  teardown, meaning the store would not be left clean for subsequent operations

Version 0.1
-----------

- initial release
